***********************************

*           Table S4              *

***********************************

clear

use data/PISA12_OK.dta,clear

cap log c
log using log/Tables_S4.log, replace


foreach i in pv1scie pv2scie pv3scie pv4scie pv5scie {

gen w_fstuwt2= w_fstuwt if `i'!=.m & `i'!=.

* variables of interest are standardized to have 0 mean and s.d. 1 in each country (accounting for weights) 

egen num = total(`i' * w_fstuwt2) , by(cnt) 
egen sumwt = total(w_fstuwt2), by(cnt) 
gen wtmean = num/sumwt

egen double CSS=total(w_fstuwt2*(`i'-wtmean)^2) , by(cnt)
gen double variance=CSS/sumwt
gen double `i'_std_c=(`i'-wtmean)/sqrt(variance)
drop sumwt wtmean num
drop variance CSS

* variables of interest are standardized to have 0 mean and s.d. 1 worldwide (accounting for weights) 

egen num = total(`i' * w_fstuwt2) 
egen sumwt = total(w_fstuwt2) 
gen wtmean = num/sumwt

egen double CSS=total(w_fstuwt2*(`i'-wtmean)^2) 
gen double variance=CSS/sumwt
gen double `i'_std=(`i'-wtmean)/sqrt(variance)
drop sumwt wtmean num
drop variance CSS

drop w_fstuwt2
}

* adding more and more controls for students' performance:

foreach var in pv1MR_std_c pv2MR_std_c pv3MR_std_c pv4MR_std_c  pv5MR_std_c   pv1math_std_c pv2math_std_c pv3math_std_c pv4math_std_c pv5math_std_c  pv1read_std_c pv2read_std_c pv3read_std_c pv4read_std_c pv5read_std_c {
forval i=2/5 {
gen `var'_`i'=(`var')^(`i')
}
}


forval i=1/5 {
gen pv`i'mathread=pv`i'math_std_c *  pv`i'read_std_c
gen pv`i'mathscie=pv`i'math_std_c *  pv`i'scie_std_c
gen pv`i'readscie=pv`i'read_std_c *  pv`i'scie_std_c
gen pv`i'mathreadscie=pv`i'math_std_c * pv`i'read_std_c *  pv`i'scie_std_c
}

xi i.cnt

***************************

*        Results          *

***************************



repest PISA, estimate(stata: reg matintfc_std_c girl pv@MR_std_c )
outreg2      using Tables/TableS4_variousabilitycontrols.xls,  replace excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c)

repest PISA, estimate(stata: reg matintfc_std_c girl pv@MR_std_c wealth cultpos iscedd escs st08q01 st09q01 _Icnt*) 
outreg2 using Tables/TableS4_variousabilitycontrols.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c) ///
																	drop(wealth cultpos iscedd escs st08q01 st09q01  _Icnt*)

repest PISA, estimate(stata: reg matintfc_std_c girl pv@MR_std_c* ) 
outreg2 girl using Tables/TableS4_variousabilitycontrols.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c) 

repest PISA, estimate(stata: reg matintfc_std_c girl pv@MR_std_c* pv@math_std_c* pv@read_std_c* )
outreg2 girl using Tables/TableS4_variousabilitycontrols.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c) 

repest PISA, estimate(stata: reg matintfc_std_c girl pv@MR_std_c*  pv@scie_std_c )
outreg2  using Tables/TableS4_variousabilitycontrols.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c) 

repest PISA, estimate(stata: reg matintfc_std_c girl pv@math_std_c* pv@read_std_c* pv@scie_std_c* pv@MR_std_c*)
outreg2  girl using Tables/TableS4_variousabilitycontrols.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c) 

repest PISA, estimate(stata: reg matintfc_std_c girl pv@math_std_c* pv@read_std_c* pv@scie_std_c* pv@mathread pv@mathscie pv@readscie pv@mathreadscie pv@MR_std_c*)
outreg2 girl using Tables/TableS4_variousabilitycontrols.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c) 

repest PISA, estimate(stata: reg matintfc_std_c girl pv@math_std_c* pv@read_std_c* pv@scie_std_c* pv@MR_std_c* pv@mathread pv@mathscie pv@readscie pv@mathreadscie  wealth cultpos iscedd escs st08q01 st09q01   _Icnt*)
outreg2 girl using Tables/TableS4_variousabilitycontrols.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c) ///
																							drop(wealth cultpos iscedd escs st08q01 st09q01   _Icnt*) 

* oecd only

repest PISA, estimate(stata: reg matintfc_std_c girl pv@MR_std_c if oecd==1)
outreg2      using Tables/TableS4_variousabilitycontrols.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c)

repest PISA, estimate(stata: reg matintfc_std_c girl pv@MR_std_c wealth cultpos iscedd escs st08q01 st09q01 _Icnt*  if oecd==1) 
outreg2 using Tables/TableS4_variousabilitycontrols.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c) ///
																	drop(wealth cultpos iscedd escs st08q01 st09q01  _Icnt*)

repest PISA, estimate(stata: reg matintfc_std_c girl pv@MR_std_c* if oecd==1) 
outreg2 girl using Tables/TableS4_variousabilitycontrols.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c) 

repest PISA, estimate(stata: reg matintfc_std_c girl pv@MR_std_c* pv@math_std_c* pv@read_std_c* if oecd==1)
outreg2 girl using Tables/TableS4_variousabilitycontrols.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c) 

repest PISA, estimate(stata: reg matintfc_std_c girl pv@MR_std_c*  pv@scie_std_c if oecd==1)
outreg2  using Tables/TableS4_variousabilitycontrols.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c) 

repest PISA, estimate(stata: reg matintfc_std_c girl pv@math_std_c* pv@read_std_c* pv@scie_std_c* pv@MR_std_c* if oecd==1)
outreg2  girl using Tables/TableS4_variousabilitycontrols.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c) 

repest PISA, estimate(stata: reg matintfc_std_c girl pv@math_std_c* pv@read_std_c* pv@scie_std_c* pv@mathread pv@mathscie pv@readscie pv@mathreadscie pv@MR_std_c* if oecd==1)
outreg2 girl using Tables/TableS4_variousabilitycontrols.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c) 

repest PISA, estimate(stata: reg matintfc_std_c girl pv@math_std_c* pv@read_std_c* pv@scie_std_c* pv@MR_std_c* pv@mathread pv@mathscie pv@readscie pv@mathreadscie  wealth cultpos iscedd escs st08q01 st09q01   _Icnt*  if oecd==1)
outreg2 girl using Tables/TableS4_variousabilitycontrols.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   sortvar(pv_MR_std_c pv_math_std_c pv_math_std_c pv_read_std_c pv_scie_std_c) ///
																							drop(wealth cultpos iscedd escs st08q01 st09q01   _Icnt*) 

******************************************************************
******************************************************************
																							
* N obs, and R2 retrieved from simple regressions below

reg matintfc_std_c girl pv1MR_std_c [weight=w_fstuwt ]
outreg2  girl using Tables/TableS4_R2Nobs.xls,  replace excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) 

reg matintfc_std_c girl pv1MR_std_c wealth cultpos iscedd escs st08q01 st09q01   _Icnt* [weight=w_fstuwt ]
outreg2 girl using Tables/TableS4_R2Nobs.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) 

reg matintfc_std_c girl pv1MR_std_c*   [weight=w_fstuwt ]
outreg2 girl using Tables/TableS4_R2Nobs.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) 

reg matintfc_std_c girl pv1math_std_c* pv1read_std_c*  pv1MR_std_c* [weight=w_fstuwt ]
outreg2 girl using Tables/TableS4_R2Nobs.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) 

reg matintfc_std_c girl  pv1MR_std_c   pv1scie_std_c pv1MR_std_c* [weight=w_fstuwt ]
outreg2 girl using Tables/TableS4_R2Nobs.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   

reg matintfc_std_c girl pv1math_std_c* pv1read_std_c* pv1scie_std_c*  pv1MR_std_c* [weight=w_fstuwt ]
outreg2 girl using Tables/TableS4_R2Nobs.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) 

reg matintfc_std_c girl pv1math_std_c* pv1read_std_c* pv1scie_std_c* pv1mathread pv1mathscie pv1readscie pv1mathreadscie pv1MR_std_c* [weight=w_fstuwt ]
outreg2  girl using Tables/TableS4_R2Nobs.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) 

reg matintfc_std_c girl  pv1math_std_c*  pv1read_std_c*  pv1scie_std_c*  pv1mathread  pv1mathscie  pv1readscie  pv1mathreadscie  wealth cultpos iscedd escs st08q01 st09q01 _Icnt* pv1MR_std_c* [weight=w_fstuwt ]
outreg2  girl using Tables/TableS4_R2Nobs.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) 


****** OECD only
reg matintfc_std_c girl pv1MR_std_c [weight=w_fstuwt ] if oecd==1
outreg2  girl using Tables/TableS4_R2Nobs.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) 

reg matintfc_std_c girl  pv1MR_std_c wealth cultpos iscedd escs st08q01 st09q01   _Icnt* [weight=w_fstuwt ] if oecd==1
outreg2 girl using Tables/TableS4_R2Nobs.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) 

reg matintfc_std_c girl pv1MR_std_c*  [weight=w_fstuwt ] if oecd==1
outreg2 girl using Tables/TableS4_R2Nobs.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) 

reg matintfc_std_c girl pv1math_std_c* pv1read_std_c*  pv1MR_std_c* [weight=w_fstuwt ]  if oecd==1
outreg2 girl using Tables/TableS4_R2Nobs.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) 

reg matintfc_std_c girl  pv1MR_std_c  pv1scie_std_c   pv1MR_std_c* [weight=w_fstuwt ]  if oecd==1
outreg2 girl using Tables/TableS4_R2Nobs.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec)   

reg matintfc_std_c girl pv1math_std_c* pv1read_std_c* pv1scie_std_c* pv1MR_std_c* [weight=w_fstuwt ]  if oecd==1
outreg2 girl using Tables/TableS4_R2Nobs.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) 

reg matintfc_std_c girl pv1math_std_c* pv1read_std_c* pv1scie_std_c* pv1mathread pv1mathscie pv1readscie pv1mathreadscie pv1MR_std_c*  [weight=w_fstuwt ]  if oecd==1
outreg2 girl using Tables/TableS4_R2Nobs.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) 

reg matintfc_std_c girl  pv1math_std_c* pv1read_std_c*  pv1scie_std_c*  pv1mathread  pv1mathscie  pv1readscie  pv1mathreadscie  wealth cultpos iscedd escs st08q01 st09q01 _Icnt*  pv1MR_std_c* [weight=w_fstuwt ] if oecd==1
outreg2  girl using Tables/TableS4_R2Nobs.xls,  append excel $ast $adt $stat $nolabel   sdec($nbdec)  bdec($nbdec) 


/*
* for other variables
reg study_harder_math girl      [weight=w_fstuwt  ]
reg study_harder_math girl  pv1MR_std_c   [weight=w_fstuwt  ]
reg study_harder_math girl  pv1math_std_c* pv1read_std_c* pv1scie_std_c* pv1mathread pv1mathscie pv1readscie pv1mathreadscie pv1MR_std_c*   [weight=w_fstuwt  ]


reg more_course_math girl     [weight=w_fstuwt  ]
reg more_course_math girl  pv1MR_std_c   [weight=w_fstuwt  ]
reg more_course_math girl  pv1math_std_c* pv1read_std_c* pv1scie_std_c* pv1mathread pv1mathscie pv1readscie pv1mathreadscie pv1MR_std_c*   [weight=w_fstuwt  ]

reg math_futurestudy girl     [weight=w_fstuwt  ]
reg math_futurestudy girl  pv1MR_std_c   [weight=w_fstuwt  ]
reg math_futurestudy girl  pv1math_std_c* pv1read_std_c* pv1scie_std_c* pv1mathread pv1mathscie pv1readscie pv1mathreadscie pv1MR_std_c*  [weight=w_fstuwt  ]
*/
