* Note for mac users : the variables st48q01 do not define missing values as ".n,.i,or.m" but as "." as usual. 

clear

use data/PISA2012/sch.dta,clear

gen share_math_ft=  sc10q11/ sc09q11
gen share_math_pt=  sc10q12/ sc09q12
gen share_math=   (2*sc10q11+sc10q12)/   (2*sc09q11 +sc09q12 )

gen share_qual_ft= sc09q31/ sc09q11
gen share_qual_pt=sc09q32/ sc09q12
gen share_qual= (2*sc09q31  + sc09q32)/ (2* sc09q11 + sc09q12 )

gen share_qual_math_ft=sc10q61/ sc10q11
gen share_qual_math_pt=sc10q62 /sc10q12
gen share_qual_math=(2*sc10q61+sc10q62)/ (2*sc10q11+sc10q12)

gen qual_math_vs_qual=share_qual_math-share_qual

gen shortage_math_teachers=sc14q02
gen shortage_reading_teachers=sc14q03
gen MR_shortage=sc14q02-sc14q03

gen admission_residence= (sc32q07==3) if sc32q07!=.


keep cnt subnatio stratum schoolid  MR_shortage  share_math  qual_math_vs_qual clsize  pcgirls compweb respcur respres ratcmp15 tcshort admission_residence

sort cnt subnatio stratum schoolid 

save data/school_ok.dta,replace


***************************************************************************

use data/PISA2012/stu.dta,clear

**definitions**
gen girl=(st04q01==1)

keep cnt subnatio stratum schoolid stidstd w_fstuwt ///
		pv*math pv*read pv*scie   scmat   subnorm st35q05 intmat instmot anxmat matbeh  oecd ///
		matintfc st48q*  girl   w_fstr*   wealth cultpos iscedd escs st08q01 st09q01 atschl attlnact belong  st29q07

gen more_course_math= (st48q01==1) if (st48q01!=.i &  st48q01!=.m & st48q01!=.n & st48q01!=.)
gen study_harder_math= (st48q03==1) if (st48q03!=.i &  st48q03!=.m & st48q03!=.n & st48q01!=.)
gen   math_futurestudy	= 4-st29q07 
		
		
gen s_m= (pv1math+pv2math+pv3math+pv4math+pv5math)/5
gen s_r= (pv1read+pv2read+pv3read+pv4read+pv5read)/5
gen s_s= (pv1scie+pv2scie+pv3scie+pv4scie+pv5scie)/5

gen v_m= ( (pv1math-s_m)^2 + (pv2math-s_m)^2+ (pv3math-s_m)^2+(pv4math-s_m)^2+(pv5math-s_m)^2 ) /5
gen v_r= ( (pv1read-s_r)^2 + (pv2read-s_r)^2+ (pv3read-s_r)^2+(pv4read-s_r)^2+(pv5read-s_r)^2 ) /5
gen v_s= ( (pv1scie-s_r)^2 + (pv2scie-s_r)^2+ (pv3scie-s_r)^2+(pv4scie-s_r)^2+(pv5scie-s_r)^2 ) /5

gen cov_mr=  ( (pv1math-s_m)*(pv1read-s_r)  + (pv2math-s_m)*(pv2read-s_r) +(pv3math-s_m)*(pv3read-s_r)  + (pv4math-s_m)*(pv4read-s_r)  + (pv5math-s_m)*(pv5read-s_r)  ) /5

** Q: doit-on diviser par 4 ou 5 pour l'estimateur de la variance ? 

gen v_MR=v_m+v_r-2*cov_mr
gen sd_MR=sqrt(v_MR)
gen s_MR= s_m-s_r


forval i=1/5 {
gen pv`i'MR= pv`i'math - pv`i'read
gen pv`i'MR_bis= s_MR +rnormal(0, sd_MR)
}


gen v_MR_emp= ( (pv1MR-s_MR)^2 + (pv2MR-s_MR)^2+ (pv3MR-s_MR)^2+(pv4MR-s_MR)^2+(pv5MR-s_MR)^2   ) /5
gen v_MR_bis_emp= ( (pv1MR_bis-s_MR)^2 + (pv2MR_bis-s_MR)^2+ (pv3MR_bis-s_MR)^2+(pv4MR_bis-s_MR)^2+(pv5MR_bis-s_MR)^2   ) /5
gen rho_mr=cov_mr/(sqrt(v_m*v_r))

sum v_MR_emp
sum v_MR_bis_emp
sum v_MR
sum cov_mr
sum rho_mr


**** Country codes
replace cnt="USA" if cnt=="QUA" | cnt=="QUB" | cnt=="QUC"
replace cnt="RUS" if cnt=="QRS"


*********************
** Standardization **
*********************

foreach i in s_m s_r s_s matintfc scmat  intmat instmot anxmat matbeh  subnorm pv1MR pv2MR pv3MR pv4MR  pv5MR   pv1math pv2math pv3math pv4math pv5math  pv1read pv2read pv3read pv4read  pv5read  math_futurestudy {

gen w_fstuwt2= w_fstuwt if `i'!=.m & `i'!=.
*** variables of interest are standardized to have 0 mean and s.d. 1 in each country (accounting for weights) 
egen num = total(`i' * w_fstuwt2) , by(cnt) 
egen sumwt = total(w_fstuwt2), by(cnt) 
gen wtmean = num/sumwt

egen double CSS=total(w_fstuwt2*(`i'-wtmean)^2) , by(cnt)
gen double variance=CSS/sumwt
gen double `i'_std_c=(`i'-wtmean)/sqrt(variance)
drop sumwt wtmean num
drop variance CSS

*** variables of interest are standardized to have 0 mean and s.d. 1 worldwide (accounting for weights) 
egen num = total(`i' * w_fstuwt2) 
egen sumwt = total(w_fstuwt2) 
gen wtmean = num/sumwt

egen double CSS=total(w_fstuwt2*(`i'-wtmean)^2) 
gen double variance=CSS/sumwt
gen double `i'_std=(`i'-wtmean)/sqrt(variance)
drop sumwt wtmean num
drop variance CSS

drop w_fstuwt2
}




save data/PISA12_OK.dta,replace







